diff --git a/.github/ISSUE_TEMPLATE/BUG_REPORT.md b/.github/ISSUE_TEMPLATE/BUG_REPORT.md
index 02bd285027..27383512e7 100644
--- a/.github/ISSUE_TEMPLATE/BUG_REPORT.md
+++ b/.github/ISSUE_TEMPLATE/BUG_REPORT.md
@@ -13,7 +13,7 @@ https://guides.github.com/features/mastering-markdown/
Please ensure you have also read and understand the contributing guide.
-https://github.com/strapi/strapi/blob/master/CONTRIBUTING.md#reporting-an-issue
+https://github.com/strapi/strapi/blob/main/CONTRIBUTING.md#reporting-an-issue
-->
## Bug report
diff --git a/.github/PULL_REQUEST_TEMPLATE.md b/.github/PULL_REQUEST_TEMPLATE.md
index 542bf4042f..7c91f51dcf 100644
--- a/.github/PULL_REQUEST_TEMPLATE.md
+++ b/.github/PULL_REQUEST_TEMPLATE.md
@@ -8,7 +8,7 @@ To help us merge your PR, make sure to follow the instructions below:
- Refer to the issue you are closing in the PR description: Fix #issue
- Specify if the PR is ready to be merged or work in progress (by opening a draft PR)
-Please ensure you read the Contributing Guide: https://github.com/strapi/strapi/blob/master/CONTRIBUTING.md
+Please ensure you read the Contributing Guide: https://github.com/strapi/strapi/blob/main/CONTRIBUTING.md
-->
### What does it do?
diff --git a/.github/actions/check-pr-status/README.md b/.github/actions/check-pr-status/README.md
index 9d2becf5db..8d5aef5ef4 100644
--- a/.github/actions/check-pr-status/README.md
+++ b/.github/actions/check-pr-status/README.md
@@ -1,6 +1,6 @@
# PR checker for status
-This action checks a PR labels, milestone and status to validate it is ready for merging into master.
+This action checks a PR labels, milestone and status to validate it is ready for merging into main.
> ❗️ When making changes to this code, make sure to run the build before committing. See [Development](#development) to know more.
diff --git a/.github/workflows/checks.yml b/.github/workflows/checks.yml
index cdbee9aa48..2fe3c763ea 100644
--- a/.github/workflows/checks.yml
+++ b/.github/workflows/checks.yml
@@ -9,7 +9,7 @@ on:
- labeled
- unlabeled
branches:
- - master
+ - main
jobs:
check-pr-status:
diff --git a/.github/workflows/tests.yml b/.github/workflows/tests.yml
index 469491811c..4425244156 100644
--- a/.github/workflows/tests.yml
+++ b/.github/workflows/tests.yml
@@ -3,7 +3,7 @@ name: 'Tests'
on:
push:
branches:
- - master
+ - main
pull_request:
jobs:
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
deleted file mode 100644
index 06ed5905eb..0000000000
--- a/.gitlab-ci.yml
+++ /dev/null
@@ -1,10 +0,0 @@
-trigger_deploy:
- stage: deploy
- script:
- - curl -X POST
- --form "token=$TRIGGER_TOKEN"
- --form "ref=master"
- --form "variables[UPSTREAM_COMMIT_SHA]=$CI_COMMIT_SHA"
- https://gitlab.com/api/v4/projects/12825884/trigger/pipeline
- only:
- - develop
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 5d2de78792..77d9fd7401 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -1,6 +1,6 @@
# Contribute to Strapi
-Strapi is an open-source project administered by [the Strapi team](https://strapi.io/about-us). We appreciate your interest and efforts to contribute to Strapi. See the [LICENSE](https://github.com/strapi/strapi/blob/master/LICENSE) licensing information. All work done is available on GitHub.
+Strapi is an open-source project administered by [the Strapi team](https://strapi.io/about-us). We appreciate your interest and efforts to contribute to Strapi. See the [LICENSE](https://github.com/strapi/strapi/blob/main/LICENSE) licensing information. All work done is available on GitHub.
We highly appreciate your effort to contribute, but we recommend you talk to a maintainer before spending a lot of time making a pull request that may not align with the project roadmap. Whether it is from Strapi or contributors, every pull request goes through the same process.
@@ -51,7 +51,7 @@ The Strapi core team will review your pull request and either merge it, request
**Before submitting your pull request** make sure the following requirements are fulfilled:
-- Fork the repository and create your new branch from `master`.
+- Fork the repository and create your new branch from `main`.
- Run `yarn setup` in the root of the repository.
- If you've fixed a bug or added code that should be tested, please make sure to add tests
- Ensure the following test suites are passing:
diff --git a/README.md b/README.md
index ef47cd9bae..561540745c 100644
--- a/README.md
+++ b/README.md
@@ -17,7 +17,7 @@
-
+
diff --git a/codecov.yml b/codecov.yml
index c56012f895..07b2663fe4 100644
--- a/codecov.yml
+++ b/codecov.yml
@@ -1,7 +1,6 @@
comment:
branches:
- - master
- - develop
+ - main
github_checks:
annotations: false
diff --git a/docs/docusaurus.config.js b/docs/docusaurus.config.js
index cbe9ee5a45..39ed5e3f85 100644
--- a/docs/docusaurus.config.js
+++ b/docs/docusaurus.config.js
@@ -32,7 +32,7 @@ const config = {
docs: {
routeBasePath: '/',
sidebarPath: require.resolve('./sidebars.js'),
- // editUrl: 'https://github.com/strapi/strapi/tree/master/docs//docs',
+ // editUrl: 'https://github.com/strapi/strapi/tree/main/docs//docs',
},
blog: false,
},
diff --git a/packages/core/strapi/README.md b/packages/core/strapi/README.md
index ef39bde2da..575ab98e86 100644
--- a/packages/core/strapi/README.md
+++ b/packages/core/strapi/README.md
@@ -13,7 +13,7 @@
-
+
diff --git a/packages/core/utils/README.md b/packages/core/utils/README.md
index fdbd964001..ba2d7c641a 100644
--- a/packages/core/utils/README.md
+++ b/packages/core/utils/README.md
@@ -1,10 +1,7 @@
# strapi-utils
-[](https://www.npmjs.org/package/strapi-utils)
-[](https://www.npmjs.org/package/strapi-utils)
-[](https://david-dm.org/strapi/strapi-utils)
-[](https://travis-ci.org/strapi/strapi-utils)
-[](https://slack.strapi.io)
+[](https://www.npmjs.org/package/@strapi/utils)
+[](https://www.npmjs.org/package/@strapi/utils)
Shared utilities between Strapi packages.
diff --git a/scripts/publish.sh b/scripts/publish.sh
index 5c7bfd3ff4..cb76299c32 100755
--- a/scripts/publish.sh
+++ b/scripts/publish.sh
@@ -13,8 +13,8 @@ read -r version
# publish packages
./node_modules/.bin/lerna publish --no-push --force-publish --dist-tag latest --exact "$version"
-# push master branch
-git push origin master
+# push main branch
+git push origin main
# push tag
git push origin v"$version"